@@ -82,7 +82,7 @@ class KinesisAnalyticsClient:
         ApplicationName: str,
         CurrentApplicationVersionId: int,
         InputId: str,
-        InputProcessingConfiguration: InputProcessingConfigurationTypeDef,
+        InputProcessingConfiguration: "InputProcessingConfigurationTypeDef",
     ) -> Dict[str, Any]:
         """
         [Client.add_application_input_processing_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_input_processing_configuration)
@@ -118,7 +118,7 @@ class KinesisAnalyticsClient:
         Outputs: List[OutputTypeDef] = None,
         CloudWatchLoggingOptions: List[CloudWatchLoggingOptionTypeDef] = None,
         ApplicationCode: str = None,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
     ) -> CreateApplicationResponseTypeDef:
         """
         [Client.create_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.create_application)
@@ -166,9 +166,9 @@ class KinesisAnalyticsClient:
         self,
         ResourceARN: str = None,
         RoleARN: str = None,
-        InputStartingPositionConfiguration: InputStartingPositionConfigurationTypeDef = None,
+        InputStartingPositionConfiguration: "InputStartingPositionConfigurationTypeDef" = None,
         S3Configuration: S3ConfigurationTypeDef = None,
-        InputProcessingConfiguration: InputProcessingConfigurationTypeDef = None,
+        InputProcessingConfiguration: "InputProcessingConfigurationTypeDef" = None,
     ) -> DiscoverInputSchemaResponseTypeDef:
         """
         [Client.discover_input_schema documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.discover_input_schema)
@@ -209,7 +209,7 @@ class KinesisAnalyticsClient:
         [Client.stop_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.stop_application)
         """
 
-    def tag_resource(self, ResourceARN: str, Tags: List[TagTypeDef]) -> Dict[str, Any]:
+    def tag_resource(self, ResourceARN: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
         [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.tag_resource)
         """
