@@ -3,9 +3,9 @@ Main interface for kinesisanalytics service type definitions.
 
 Usage::
 
-    from mypy_boto3.kinesisanalytics.type_defs import CloudWatchLoggingOptionUpdateTypeDef
+    from mypy_boto3.kinesisanalytics.type_defs import ApplicationDetailTypeDef
 
-    data: CloudWatchLoggingOptionUpdateTypeDef = {...}
+    data: ApplicationDetailTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,270 +22,99 @@ else:
 
 
 __all__ = (
-    "CloudWatchLoggingOptionUpdateTypeDef",
-    "InputParallelismUpdateTypeDef",
-    "InputLambdaProcessorUpdateTypeDef",
-    "InputProcessingConfigurationUpdateTypeDef",
-    "RecordColumnTypeDef",
+    "ApplicationDetailTypeDef",
+    "ApplicationSummaryTypeDef",
     "CSVMappingParametersTypeDef",
-    "JSONMappingParametersTypeDef",
-    "MappingParametersTypeDef",
-    "RecordFormatTypeDef",
-    "InputSchemaUpdateTypeDef",
-    "KinesisFirehoseInputUpdateTypeDef",
-    "KinesisStreamsInputUpdateTypeDef",
-    "InputUpdateTypeDef",
+    "CloudWatchLoggingOptionDescriptionTypeDef",
+    "CloudWatchLoggingOptionUpdateTypeDef",
     "DestinationSchemaTypeDef",
+    "InputDescriptionTypeDef",
+    "InputLambdaProcessorDescriptionTypeDef",
+    "InputLambdaProcessorTypeDef",
+    "InputLambdaProcessorUpdateTypeDef",
+    "InputParallelismTypeDef",
+    "InputParallelismUpdateTypeDef",
+    "InputProcessingConfigurationDescriptionTypeDef",
+    "InputProcessingConfigurationTypeDef",
+    "InputProcessingConfigurationUpdateTypeDef",
+    "InputSchemaUpdateTypeDef",
+    "InputStartingPositionConfigurationTypeDef",
+    "InputUpdateTypeDef",
+    "JSONMappingParametersTypeDef",
+    "KinesisFirehoseInputDescriptionTypeDef",
+    "KinesisFirehoseInputTypeDef",
+    "KinesisFirehoseInputUpdateTypeDef",
+    "KinesisFirehoseOutputDescriptionTypeDef",
+    "KinesisFirehoseOutputTypeDef",
     "KinesisFirehoseOutputUpdateTypeDef",
+    "KinesisStreamsInputDescriptionTypeDef",
+    "KinesisStreamsInputTypeDef",
+    "KinesisStreamsInputUpdateTypeDef",
+    "KinesisStreamsOutputDescriptionTypeDef",
+    "KinesisStreamsOutputTypeDef",
     "KinesisStreamsOutputUpdateTypeDef",
+    "LambdaOutputDescriptionTypeDef",
+    "LambdaOutputTypeDef",
     "LambdaOutputUpdateTypeDef",
+    "MappingParametersTypeDef",
+    "OutputDescriptionTypeDef",
     "OutputUpdateTypeDef",
+    "RecordColumnTypeDef",
+    "RecordFormatTypeDef",
+    "ReferenceDataSourceDescriptionTypeDef",
+    "ReferenceDataSourceUpdateTypeDef",
+    "S3ReferenceDataSourceDescriptionTypeDef",
+    "S3ReferenceDataSourceTypeDef",
     "S3ReferenceDataSourceUpdateTypeDef",
     "SourceSchemaTypeDef",
-    "ReferenceDataSourceUpdateTypeDef",
+    "TagTypeDef",
     "ApplicationUpdateTypeDef",
     "CloudWatchLoggingOptionTypeDef",
-    "ApplicationSummaryTypeDef",
     "CreateApplicationResponseTypeDef",
-    "CloudWatchLoggingOptionDescriptionTypeDef",
-    "InputParallelismTypeDef",
-    "InputLambdaProcessorDescriptionTypeDef",
-    "InputProcessingConfigurationDescriptionTypeDef",
-    "InputStartingPositionConfigurationTypeDef",
-    "KinesisFirehoseInputDescriptionTypeDef",
-    "KinesisStreamsInputDescriptionTypeDef",
-    "InputDescriptionTypeDef",
-    "KinesisFirehoseOutputDescriptionTypeDef",
-    "KinesisStreamsOutputDescriptionTypeDef",
-    "LambdaOutputDescriptionTypeDef",
-    "OutputDescriptionTypeDef",
-    "S3ReferenceDataSourceDescriptionTypeDef",
-    "ReferenceDataSourceDescriptionTypeDef",
-    "ApplicationDetailTypeDef",
     "DescribeApplicationResponseTypeDef",
     "DiscoverInputSchemaResponseTypeDef",
     "InputConfigurationTypeDef",
-    "InputLambdaProcessorTypeDef",
-    "InputProcessingConfigurationTypeDef",
-    "KinesisFirehoseInputTypeDef",
-    "KinesisStreamsInputTypeDef",
     "InputTypeDef",
     "ListApplicationsResponseTypeDef",
-    "TagTypeDef",
     "ListTagsForResourceResponseTypeDef",
-    "KinesisFirehoseOutputTypeDef",
-    "KinesisStreamsOutputTypeDef",
-    "LambdaOutputTypeDef",
     "OutputTypeDef",
-    "S3ReferenceDataSourceTypeDef",
     "ReferenceDataSourceTypeDef",
     "S3ConfigurationTypeDef",
 )
 
-_RequiredCloudWatchLoggingOptionUpdateTypeDef = TypedDict(
-    "_RequiredCloudWatchLoggingOptionUpdateTypeDef", {"CloudWatchLoggingOptionId": str}
+_RequiredApplicationDetailTypeDef = TypedDict(
+    "_RequiredApplicationDetailTypeDef",
+    {
+        "ApplicationName": str,
+        "ApplicationARN": str,
+        "ApplicationStatus": Literal[
+            "DELETING", "STARTING", "STOPPING", "READY", "RUNNING", "UPDATING"
+        ],
+        "ApplicationVersionId": int,
+    },
 )
-_OptionalCloudWatchLoggingOptionUpdateTypeDef = TypedDict(
-    "_OptionalCloudWatchLoggingOptionUpdateTypeDef",
-    {"LogStreamARNUpdate": str, "RoleARNUpdate": str},
+_OptionalApplicationDetailTypeDef = TypedDict(
+    "_OptionalApplicationDetailTypeDef",
+    {
+        "ApplicationDescription": str,
+        "CreateTimestamp": datetime,
+        "LastUpdateTimestamp": datetime,
+        "InputDescriptions": List["InputDescriptionTypeDef"],
+        "OutputDescriptions": List["OutputDescriptionTypeDef"],
+        "ReferenceDataSourceDescriptions": List["ReferenceDataSourceDescriptionTypeDef"],
+        "CloudWatchLoggingOptionDescriptions": List["CloudWatchLoggingOptionDescriptionTypeDef"],
+        "ApplicationCode": str,
+    },
     total=False,
 )
 
 
-class CloudWatchLoggingOptionUpdateTypeDef(
-    _RequiredCloudWatchLoggingOptionUpdateTypeDef, _OptionalCloudWatchLoggingOptionUpdateTypeDef
+class ApplicationDetailTypeDef(
+    _RequiredApplicationDetailTypeDef, _OptionalApplicationDetailTypeDef
 ):
     pass
 
 
-InputParallelismUpdateTypeDef = TypedDict(
-    "InputParallelismUpdateTypeDef", {"CountUpdate": int}, total=False
-)
-
-InputLambdaProcessorUpdateTypeDef = TypedDict(
-    "InputLambdaProcessorUpdateTypeDef",
-    {"ResourceARNUpdate": str, "RoleARNUpdate": str},
-    total=False,
-)
-
-InputProcessingConfigurationUpdateTypeDef = TypedDict(
-    "InputProcessingConfigurationUpdateTypeDef",
-    {"InputLambdaProcessorUpdate": InputLambdaProcessorUpdateTypeDef},
-)
-
-_RequiredRecordColumnTypeDef = TypedDict(
-    "_RequiredRecordColumnTypeDef", {"Name": str, "SqlType": str}
-)
-_OptionalRecordColumnTypeDef = TypedDict(
-    "_OptionalRecordColumnTypeDef", {"Mapping": str}, total=False
-)
-
-
-class RecordColumnTypeDef(_RequiredRecordColumnTypeDef, _OptionalRecordColumnTypeDef):
-    pass
-
-
-CSVMappingParametersTypeDef = TypedDict(
-    "CSVMappingParametersTypeDef", {"RecordRowDelimiter": str, "RecordColumnDelimiter": str}
-)
-
-JSONMappingParametersTypeDef = TypedDict("JSONMappingParametersTypeDef", {"RecordRowPath": str})
-
-MappingParametersTypeDef = TypedDict(
-    "MappingParametersTypeDef",
-    {
-        "JSONMappingParameters": JSONMappingParametersTypeDef,
-        "CSVMappingParameters": CSVMappingParametersTypeDef,
-    },
-    total=False,
-)
-
-_RequiredRecordFormatTypeDef = TypedDict(
-    "_RequiredRecordFormatTypeDef", {"RecordFormatType": Literal["JSON", "CSV"]}
-)
-_OptionalRecordFormatTypeDef = TypedDict(
-    "_OptionalRecordFormatTypeDef", {"MappingParameters": MappingParametersTypeDef}, total=False
-)
-
-
-class RecordFormatTypeDef(_RequiredRecordFormatTypeDef, _OptionalRecordFormatTypeDef):
-    pass
-
-
-InputSchemaUpdateTypeDef = TypedDict(
-    "InputSchemaUpdateTypeDef",
-    {
-        "RecordFormatUpdate": RecordFormatTypeDef,
-        "RecordEncodingUpdate": str,
-        "RecordColumnUpdates": List[RecordColumnTypeDef],
-    },
-    total=False,
-)
-
-KinesisFirehoseInputUpdateTypeDef = TypedDict(
-    "KinesisFirehoseInputUpdateTypeDef",
-    {"ResourceARNUpdate": str, "RoleARNUpdate": str},
-    total=False,
-)
-
-KinesisStreamsInputUpdateTypeDef = TypedDict(
-    "KinesisStreamsInputUpdateTypeDef",
-    {"ResourceARNUpdate": str, "RoleARNUpdate": str},
-    total=False,
-)
-
-_RequiredInputUpdateTypeDef = TypedDict("_RequiredInputUpdateTypeDef", {"InputId": str})
-_OptionalInputUpdateTypeDef = TypedDict(
-    "_OptionalInputUpdateTypeDef",
-    {
-        "NamePrefixUpdate": str,
-        "InputProcessingConfigurationUpdate": InputProcessingConfigurationUpdateTypeDef,
-        "KinesisStreamsInputUpdate": KinesisStreamsInputUpdateTypeDef,
-        "KinesisFirehoseInputUpdate": KinesisFirehoseInputUpdateTypeDef,
-        "InputSchemaUpdate": InputSchemaUpdateTypeDef,
-        "InputParallelismUpdate": InputParallelismUpdateTypeDef,
-    },
-    total=False,
-)
-
-
-class InputUpdateTypeDef(_RequiredInputUpdateTypeDef, _OptionalInputUpdateTypeDef):
-    pass
-
-
-DestinationSchemaTypeDef = TypedDict(
-    "DestinationSchemaTypeDef", {"RecordFormatType": Literal["JSON", "CSV"]}
-)
-
-KinesisFirehoseOutputUpdateTypeDef = TypedDict(
-    "KinesisFirehoseOutputUpdateTypeDef",
-    {"ResourceARNUpdate": str, "RoleARNUpdate": str},
-    total=False,
-)
-
-KinesisStreamsOutputUpdateTypeDef = TypedDict(
-    "KinesisStreamsOutputUpdateTypeDef",
-    {"ResourceARNUpdate": str, "RoleARNUpdate": str},
-    total=False,
-)
-
-LambdaOutputUpdateTypeDef = TypedDict(
-    "LambdaOutputUpdateTypeDef", {"ResourceARNUpdate": str, "RoleARNUpdate": str}, total=False
-)
-
-_RequiredOutputUpdateTypeDef = TypedDict("_RequiredOutputUpdateTypeDef", {"OutputId": str})
-_OptionalOutputUpdateTypeDef = TypedDict(
-    "_OptionalOutputUpdateTypeDef",
-    {
-        "NameUpdate": str,
-        "KinesisStreamsOutputUpdate": KinesisStreamsOutputUpdateTypeDef,
-        "KinesisFirehoseOutputUpdate": KinesisFirehoseOutputUpdateTypeDef,
-        "LambdaOutputUpdate": LambdaOutputUpdateTypeDef,
-        "DestinationSchemaUpdate": DestinationSchemaTypeDef,
-    },
-    total=False,
-)
-
-
-class OutputUpdateTypeDef(_RequiredOutputUpdateTypeDef, _OptionalOutputUpdateTypeDef):
-    pass
-
-
-S3ReferenceDataSourceUpdateTypeDef = TypedDict(
-    "S3ReferenceDataSourceUpdateTypeDef",
-    {"BucketARNUpdate": str, "FileKeyUpdate": str, "ReferenceRoleARNUpdate": str},
-    total=False,
-)
-
-_RequiredSourceSchemaTypeDef = TypedDict(
-    "_RequiredSourceSchemaTypeDef",
-    {"RecordFormat": RecordFormatTypeDef, "RecordColumns": List[RecordColumnTypeDef]},
-)
-_OptionalSourceSchemaTypeDef = TypedDict(
-    "_OptionalSourceSchemaTypeDef", {"RecordEncoding": str}, total=False
-)
-
-
-class SourceSchemaTypeDef(_RequiredSourceSchemaTypeDef, _OptionalSourceSchemaTypeDef):
-    pass
-
-
-_RequiredReferenceDataSourceUpdateTypeDef = TypedDict(
-    "_RequiredReferenceDataSourceUpdateTypeDef", {"ReferenceId": str}
-)
-_OptionalReferenceDataSourceUpdateTypeDef = TypedDict(
-    "_OptionalReferenceDataSourceUpdateTypeDef",
-    {
-        "TableNameUpdate": str,
-        "S3ReferenceDataSourceUpdate": S3ReferenceDataSourceUpdateTypeDef,
-        "ReferenceSchemaUpdate": SourceSchemaTypeDef,
-    },
-    total=False,
-)
-
-
-class ReferenceDataSourceUpdateTypeDef(
-    _RequiredReferenceDataSourceUpdateTypeDef, _OptionalReferenceDataSourceUpdateTypeDef
-):
-    pass
-
-
-ApplicationUpdateTypeDef = TypedDict(
-    "ApplicationUpdateTypeDef",
-    {
-        "InputUpdates": List[InputUpdateTypeDef],
-        "ApplicationCodeUpdate": str,
-        "OutputUpdates": List[OutputUpdateTypeDef],
-        "ReferenceDataSourceUpdates": List[ReferenceDataSourceUpdateTypeDef],
-        "CloudWatchLoggingOptionUpdates": List[CloudWatchLoggingOptionUpdateTypeDef],
-    },
-    total=False,
-)
-
-CloudWatchLoggingOptionTypeDef = TypedDict(
-    "CloudWatchLoggingOptionTypeDef", {"LogStreamARN": str, "RoleARN": str}
-)
-
 ApplicationSummaryTypeDef = TypedDict(
     "ApplicationSummaryTypeDef",
     {
@@ -297,8 +126,8 @@ ApplicationSummaryTypeDef = TypedDict(
     },
 )
 
-CreateApplicationResponseTypeDef = TypedDict(
-    "CreateApplicationResponseTypeDef", {"ApplicationSummary": ApplicationSummaryTypeDef}
+CSVMappingParametersTypeDef = TypedDict(
+    "CSVMappingParametersTypeDef", {"RecordRowDelimiter": str, "RecordColumnDelimiter": str}
 )
 
 _RequiredCloudWatchLoggingOptionDescriptionTypeDef = TypedDict(
@@ -318,15 +147,84 @@ class CloudWatchLoggingOptionDescriptionTypeDef(
     pass
 
 
-InputParallelismTypeDef = TypedDict("InputParallelismTypeDef", {"Count": int}, total=False)
+_RequiredCloudWatchLoggingOptionUpdateTypeDef = TypedDict(
+    "_RequiredCloudWatchLoggingOptionUpdateTypeDef", {"CloudWatchLoggingOptionId": str}
+)
+_OptionalCloudWatchLoggingOptionUpdateTypeDef = TypedDict(
+    "_OptionalCloudWatchLoggingOptionUpdateTypeDef",
+    {"LogStreamARNUpdate": str, "RoleARNUpdate": str},
+    total=False,
+)
+
+
+class CloudWatchLoggingOptionUpdateTypeDef(
+    _RequiredCloudWatchLoggingOptionUpdateTypeDef, _OptionalCloudWatchLoggingOptionUpdateTypeDef
+):
+    pass
+
+
+DestinationSchemaTypeDef = TypedDict(
+    "DestinationSchemaTypeDef", {"RecordFormatType": Literal["JSON", "CSV"]}
+)
+
+InputDescriptionTypeDef = TypedDict(
+    "InputDescriptionTypeDef",
+    {
+        "InputId": str,
+        "NamePrefix": str,
+        "InAppStreamNames": List[str],
+        "InputProcessingConfigurationDescription": "InputProcessingConfigurationDescriptionTypeDef",
+        "KinesisStreamsInputDescription": "KinesisStreamsInputDescriptionTypeDef",
+        "KinesisFirehoseInputDescription": "KinesisFirehoseInputDescriptionTypeDef",
+        "InputSchema": "SourceSchemaTypeDef",
+        "InputParallelism": "InputParallelismTypeDef",
+        "InputStartingPositionConfiguration": "InputStartingPositionConfigurationTypeDef",
+    },
+    total=False,
+)
 
 InputLambdaProcessorDescriptionTypeDef = TypedDict(
     "InputLambdaProcessorDescriptionTypeDef", {"ResourceARN": str, "RoleARN": str}, total=False
 )
 
+InputLambdaProcessorTypeDef = TypedDict(
+    "InputLambdaProcessorTypeDef", {"ResourceARN": str, "RoleARN": str}
+)
+
+InputLambdaProcessorUpdateTypeDef = TypedDict(
+    "InputLambdaProcessorUpdateTypeDef",
+    {"ResourceARNUpdate": str, "RoleARNUpdate": str},
+    total=False,
+)
+
+InputParallelismTypeDef = TypedDict("InputParallelismTypeDef", {"Count": int}, total=False)
+
+InputParallelismUpdateTypeDef = TypedDict(
+    "InputParallelismUpdateTypeDef", {"CountUpdate": int}, total=False
+)
+
 InputProcessingConfigurationDescriptionTypeDef = TypedDict(
     "InputProcessingConfigurationDescriptionTypeDef",
-    {"InputLambdaProcessorDescription": InputLambdaProcessorDescriptionTypeDef},
+    {"InputLambdaProcessorDescription": "InputLambdaProcessorDescriptionTypeDef"},
+    total=False,
+)
+
+InputProcessingConfigurationTypeDef = TypedDict(
+    "InputProcessingConfigurationTypeDef", {"InputLambdaProcessor": "InputLambdaProcessorTypeDef"}
+)
+
+InputProcessingConfigurationUpdateTypeDef = TypedDict(
+    "InputProcessingConfigurationUpdateTypeDef",
+    {"InputLambdaProcessorUpdate": "InputLambdaProcessorUpdateTypeDef"},
+)
+
+InputSchemaUpdateTypeDef = TypedDict(
+    "InputSchemaUpdateTypeDef",
+    {
+        "RecordFormatUpdate": "RecordFormatTypeDef",
+        "RecordEncodingUpdate": str,
+        "RecordColumnUpdates": List["RecordColumnTypeDef"],
+    },
     total=False,
 )
 
@@ -336,27 +234,38 @@ InputStartingPositionConfigurationTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredInputUpdateTypeDef = TypedDict("_RequiredInputUpdateTypeDef", {"InputId": str})
+_OptionalInputUpdateTypeDef = TypedDict(
+    "_OptionalInputUpdateTypeDef",
+    {
+        "NamePrefixUpdate": str,
+        "InputProcessingConfigurationUpdate": "InputProcessingConfigurationUpdateTypeDef",
+        "KinesisStreamsInputUpdate": "KinesisStreamsInputUpdateTypeDef",
+        "KinesisFirehoseInputUpdate": "KinesisFirehoseInputUpdateTypeDef",
+        "InputSchemaUpdate": "InputSchemaUpdateTypeDef",
+        "InputParallelismUpdate": "InputParallelismUpdateTypeDef",
+    },
+    total=False,
+)
+
+
+class InputUpdateTypeDef(_RequiredInputUpdateTypeDef, _OptionalInputUpdateTypeDef):
+    pass
+
+
+JSONMappingParametersTypeDef = TypedDict("JSONMappingParametersTypeDef", {"RecordRowPath": str})
+
 KinesisFirehoseInputDescriptionTypeDef = TypedDict(
     "KinesisFirehoseInputDescriptionTypeDef", {"ResourceARN": str, "RoleARN": str}, total=False
 )
 
-KinesisStreamsInputDescriptionTypeDef = TypedDict(
-    "KinesisStreamsInputDescriptionTypeDef", {"ResourceARN": str, "RoleARN": str}, total=False
+KinesisFirehoseInputTypeDef = TypedDict(
+    "KinesisFirehoseInputTypeDef", {"ResourceARN": str, "RoleARN": str}
 )
 
-InputDescriptionTypeDef = TypedDict(
-    "InputDescriptionTypeDef",
-    {
-        "InputId": str,
-        "NamePrefix": str,
-        "InAppStreamNames": List[str],
-        "InputProcessingConfigurationDescription": InputProcessingConfigurationDescriptionTypeDef,
-        "KinesisStreamsInputDescription": KinesisStreamsInputDescriptionTypeDef,
-        "KinesisFirehoseInputDescription": KinesisFirehoseInputDescriptionTypeDef,
-        "InputSchema": SourceSchemaTypeDef,
-        "InputParallelism": InputParallelismTypeDef,
-        "InputStartingPositionConfiguration": InputStartingPositionConfigurationTypeDef,
-    },
+KinesisFirehoseInputUpdateTypeDef = TypedDict(
+    "KinesisFirehoseInputUpdateTypeDef",
+    {"ResourceARNUpdate": str, "RoleARNUpdate": str},
     total=False,
 )
 
@@ -364,43 +273,129 @@ KinesisFirehoseOutputDescriptionTypeDef = TypedDict(
     "KinesisFirehoseOutputDescriptionTypeDef", {"ResourceARN": str, "RoleARN": str}, total=False
 )
 
+KinesisFirehoseOutputTypeDef = TypedDict(
+    "KinesisFirehoseOutputTypeDef", {"ResourceARN": str, "RoleARN": str}
+)
+
+KinesisFirehoseOutputUpdateTypeDef = TypedDict(
+    "KinesisFirehoseOutputUpdateTypeDef",
+    {"ResourceARNUpdate": str, "RoleARNUpdate": str},
+    total=False,
+)
+
+KinesisStreamsInputDescriptionTypeDef = TypedDict(
+    "KinesisStreamsInputDescriptionTypeDef", {"ResourceARN": str, "RoleARN": str}, total=False
+)
+
+KinesisStreamsInputTypeDef = TypedDict(
+    "KinesisStreamsInputTypeDef", {"ResourceARN": str, "RoleARN": str}
+)
+
+KinesisStreamsInputUpdateTypeDef = TypedDict(
+    "KinesisStreamsInputUpdateTypeDef",
+    {"ResourceARNUpdate": str, "RoleARNUpdate": str},
+    total=False,
+)
+
 KinesisStreamsOutputDescriptionTypeDef = TypedDict(
     "KinesisStreamsOutputDescriptionTypeDef", {"ResourceARN": str, "RoleARN": str}, total=False
 )
 
+KinesisStreamsOutputTypeDef = TypedDict(
+    "KinesisStreamsOutputTypeDef", {"ResourceARN": str, "RoleARN": str}
+)
+
+KinesisStreamsOutputUpdateTypeDef = TypedDict(
+    "KinesisStreamsOutputUpdateTypeDef",
+    {"ResourceARNUpdate": str, "RoleARNUpdate": str},
+    total=False,
+)
+
 LambdaOutputDescriptionTypeDef = TypedDict(
     "LambdaOutputDescriptionTypeDef", {"ResourceARN": str, "RoleARN": str}, total=False
 )
 
+LambdaOutputTypeDef = TypedDict("LambdaOutputTypeDef", {"ResourceARN": str, "RoleARN": str})
+
+LambdaOutputUpdateTypeDef = TypedDict(
+    "LambdaOutputUpdateTypeDef", {"ResourceARNUpdate": str, "RoleARNUpdate": str}, total=False
+)
+
+MappingParametersTypeDef = TypedDict(
+    "MappingParametersTypeDef",
+    {
+        "JSONMappingParameters": "JSONMappingParametersTypeDef",
+        "CSVMappingParameters": "CSVMappingParametersTypeDef",
+    },
+    total=False,
+)
+
 OutputDescriptionTypeDef = TypedDict(
     "OutputDescriptionTypeDef",
     {
         "OutputId": str,
         "Name": str,
-        "KinesisStreamsOutputDescription": KinesisStreamsOutputDescriptionTypeDef,
-        "KinesisFirehoseOutputDescription": KinesisFirehoseOutputDescriptionTypeDef,
-        "LambdaOutputDescription": LambdaOutputDescriptionTypeDef,
-        "DestinationSchema": DestinationSchemaTypeDef,
+        "KinesisStreamsOutputDescription": "KinesisStreamsOutputDescriptionTypeDef",
+        "KinesisFirehoseOutputDescription": "KinesisFirehoseOutputDescriptionTypeDef",
+        "LambdaOutputDescription": "LambdaOutputDescriptionTypeDef",
+        "DestinationSchema": "DestinationSchemaTypeDef",
     },
     total=False,
 )
 
-S3ReferenceDataSourceDescriptionTypeDef = TypedDict(
-    "S3ReferenceDataSourceDescriptionTypeDef",
-    {"BucketARN": str, "FileKey": str, "ReferenceRoleARN": str},
+_RequiredOutputUpdateTypeDef = TypedDict("_RequiredOutputUpdateTypeDef", {"OutputId": str})
+_OptionalOutputUpdateTypeDef = TypedDict(
+    "_OptionalOutputUpdateTypeDef",
+    {
+        "NameUpdate": str,
+        "KinesisStreamsOutputUpdate": "KinesisStreamsOutputUpdateTypeDef",
+        "KinesisFirehoseOutputUpdate": "KinesisFirehoseOutputUpdateTypeDef",
+        "LambdaOutputUpdate": "LambdaOutputUpdateTypeDef",
+        "DestinationSchemaUpdate": "DestinationSchemaTypeDef",
+    },
+    total=False,
 )
 
+
+class OutputUpdateTypeDef(_RequiredOutputUpdateTypeDef, _OptionalOutputUpdateTypeDef):
+    pass
+
+
+_RequiredRecordColumnTypeDef = TypedDict(
+    "_RequiredRecordColumnTypeDef", {"Name": str, "SqlType": str}
+)
+_OptionalRecordColumnTypeDef = TypedDict(
+    "_OptionalRecordColumnTypeDef", {"Mapping": str}, total=False
+)
+
+
+class RecordColumnTypeDef(_RequiredRecordColumnTypeDef, _OptionalRecordColumnTypeDef):
+    pass
+
+
+_RequiredRecordFormatTypeDef = TypedDict(
+    "_RequiredRecordFormatTypeDef", {"RecordFormatType": Literal["JSON", "CSV"]}
+)
+_OptionalRecordFormatTypeDef = TypedDict(
+    "_OptionalRecordFormatTypeDef", {"MappingParameters": "MappingParametersTypeDef"}, total=False
+)
+
+
+class RecordFormatTypeDef(_RequiredRecordFormatTypeDef, _OptionalRecordFormatTypeDef):
+    pass
+
+
 _RequiredReferenceDataSourceDescriptionTypeDef = TypedDict(
     "_RequiredReferenceDataSourceDescriptionTypeDef",
     {
         "ReferenceId": str,
         "TableName": str,
-        "S3ReferenceDataSourceDescription": S3ReferenceDataSourceDescriptionTypeDef,
+        "S3ReferenceDataSourceDescription": "S3ReferenceDataSourceDescriptionTypeDef",
     },
 )
 _OptionalReferenceDataSourceDescriptionTypeDef = TypedDict(
     "_OptionalReferenceDataSourceDescriptionTypeDef",
-    {"ReferenceSchema": SourceSchemaTypeDef},
+    {"ReferenceSchema": "SourceSchemaTypeDef"},
     total=False,
 )
 
@@ -411,47 +406,90 @@ class ReferenceDataSourceDescriptionTypeDef(
     pass
 
 
-_RequiredApplicationDetailTypeDef = TypedDict(
-    "_RequiredApplicationDetailTypeDef",
-    {
-        "ApplicationName": str,
-        "ApplicationARN": str,
-        "ApplicationStatus": Literal[
-            "DELETING", "STARTING", "STOPPING", "READY", "RUNNING", "UPDATING"
-        ],
-        "ApplicationVersionId": int,
-    },
+_RequiredReferenceDataSourceUpdateTypeDef = TypedDict(
+    "_RequiredReferenceDataSourceUpdateTypeDef", {"ReferenceId": str}
 )
-_OptionalApplicationDetailTypeDef = TypedDict(
-    "_OptionalApplicationDetailTypeDef",
+_OptionalReferenceDataSourceUpdateTypeDef = TypedDict(
+    "_OptionalReferenceDataSourceUpdateTypeDef",
     {
-        "ApplicationDescription": str,
-        "CreateTimestamp": datetime,
-        "LastUpdateTimestamp": datetime,
-        "InputDescriptions": List[InputDescriptionTypeDef],
-        "OutputDescriptions": List[OutputDescriptionTypeDef],
-        "ReferenceDataSourceDescriptions": List[ReferenceDataSourceDescriptionTypeDef],
-        "CloudWatchLoggingOptionDescriptions": List[CloudWatchLoggingOptionDescriptionTypeDef],
-        "ApplicationCode": str,
+        "TableNameUpdate": str,
+        "S3ReferenceDataSourceUpdate": "S3ReferenceDataSourceUpdateTypeDef",
+        "ReferenceSchemaUpdate": "SourceSchemaTypeDef",
     },
     total=False,
 )
 
 
-class ApplicationDetailTypeDef(
-    _RequiredApplicationDetailTypeDef, _OptionalApplicationDetailTypeDef
+class ReferenceDataSourceUpdateTypeDef(
+    _RequiredReferenceDataSourceUpdateTypeDef, _OptionalReferenceDataSourceUpdateTypeDef
 ):
     pass
 
 
+S3ReferenceDataSourceDescriptionTypeDef = TypedDict(
+    "S3ReferenceDataSourceDescriptionTypeDef",
+    {"BucketARN": str, "FileKey": str, "ReferenceRoleARN": str},
+)
+
+S3ReferenceDataSourceTypeDef = TypedDict(
+    "S3ReferenceDataSourceTypeDef", {"BucketARN": str, "FileKey": str, "ReferenceRoleARN": str}
+)
+
+S3ReferenceDataSourceUpdateTypeDef = TypedDict(
+    "S3ReferenceDataSourceUpdateTypeDef",
+    {"BucketARNUpdate": str, "FileKeyUpdate": str, "ReferenceRoleARNUpdate": str},
+    total=False,
+)
+
+_RequiredSourceSchemaTypeDef = TypedDict(
+    "_RequiredSourceSchemaTypeDef",
+    {"RecordFormat": "RecordFormatTypeDef", "RecordColumns": List["RecordColumnTypeDef"]},
+)
+_OptionalSourceSchemaTypeDef = TypedDict(
+    "_OptionalSourceSchemaTypeDef", {"RecordEncoding": str}, total=False
+)
+
+
+class SourceSchemaTypeDef(_RequiredSourceSchemaTypeDef, _OptionalSourceSchemaTypeDef):
+    pass
+
+
+_RequiredTagTypeDef = TypedDict("_RequiredTagTypeDef", {"Key": str})
+_OptionalTagTypeDef = TypedDict("_OptionalTagTypeDef", {"Value": str}, total=False)
+
+
+class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
+    pass
+
+
+ApplicationUpdateTypeDef = TypedDict(
+    "ApplicationUpdateTypeDef",
+    {
+        "InputUpdates": List["InputUpdateTypeDef"],
+        "ApplicationCodeUpdate": str,
+        "OutputUpdates": List["OutputUpdateTypeDef"],
+        "ReferenceDataSourceUpdates": List["ReferenceDataSourceUpdateTypeDef"],
+        "CloudWatchLoggingOptionUpdates": List["CloudWatchLoggingOptionUpdateTypeDef"],
+    },
+    total=False,
+)
+
+CloudWatchLoggingOptionTypeDef = TypedDict(
+    "CloudWatchLoggingOptionTypeDef", {"LogStreamARN": str, "RoleARN": str}
+)
+
+CreateApplicationResponseTypeDef = TypedDict(
+    "CreateApplicationResponseTypeDef", {"ApplicationSummary": "ApplicationSummaryTypeDef"}
+)
+
 DescribeApplicationResponseTypeDef = TypedDict(
-    "DescribeApplicationResponseTypeDef", {"ApplicationDetail": ApplicationDetailTypeDef}
+    "DescribeApplicationResponseTypeDef", {"ApplicationDetail": "ApplicationDetailTypeDef"}
 )
 
 DiscoverInputSchemaResponseTypeDef = TypedDict(
     "DiscoverInputSchemaResponseTypeDef",
     {
-        "InputSchema": SourceSchemaTypeDef,
+        "InputSchema": "SourceSchemaTypeDef",
         "ParsedInputRecords": List[List[str]],
         "ProcessedInputRecords": List[str],
         "RawInputRecords": List[str],
@@ -461,35 +499,19 @@ DiscoverInputSchemaResponseTypeDef = TypedDict(
 
 InputConfigurationTypeDef = TypedDict(
     "InputConfigurationTypeDef",
-    {"Id": str, "InputStartingPositionConfiguration": InputStartingPositionConfigurationTypeDef},
-)
-
-InputLambdaProcessorTypeDef = TypedDict(
-    "InputLambdaProcessorTypeDef", {"ResourceARN": str, "RoleARN": str}
-)
-
-InputProcessingConfigurationTypeDef = TypedDict(
-    "InputProcessingConfigurationTypeDef", {"InputLambdaProcessor": InputLambdaProcessorTypeDef}
-)
-
-KinesisFirehoseInputTypeDef = TypedDict(
-    "KinesisFirehoseInputTypeDef", {"ResourceARN": str, "RoleARN": str}
-)
-
-KinesisStreamsInputTypeDef = TypedDict(
-    "KinesisStreamsInputTypeDef", {"ResourceARN": str, "RoleARN": str}
+    {"Id": str, "InputStartingPositionConfiguration": "InputStartingPositionConfigurationTypeDef"},
 )
 
 _RequiredInputTypeDef = TypedDict(
-    "_RequiredInputTypeDef", {"NamePrefix": str, "InputSchema": SourceSchemaTypeDef}
+    "_RequiredInputTypeDef", {"NamePrefix": str, "InputSchema": "SourceSchemaTypeDef"}
 )
 _OptionalInputTypeDef = TypedDict(
     "_OptionalInputTypeDef",
     {
-        "InputProcessingConfiguration": InputProcessingConfigurationTypeDef,
-        "KinesisStreamsInput": KinesisStreamsInputTypeDef,
-        "KinesisFirehoseInput": KinesisFirehoseInputTypeDef,
-        "InputParallelism": InputParallelismTypeDef,
+        "InputProcessingConfiguration": "InputProcessingConfigurationTypeDef",
+        "KinesisStreamsInput": "KinesisStreamsInputTypeDef",
+        "KinesisFirehoseInput": "KinesisFirehoseInputTypeDef",
+        "InputParallelism": "InputParallelismTypeDef",
     },
     total=False,
 )
@@ -501,40 +523,22 @@ class InputTypeDef(_RequiredInputTypeDef, _OptionalInputTypeDef):
 
 ListApplicationsResponseTypeDef = TypedDict(
     "ListApplicationsResponseTypeDef",
-    {"ApplicationSummaries": List[ApplicationSummaryTypeDef], "HasMoreApplications": bool},
+    {"ApplicationSummaries": List["ApplicationSummaryTypeDef"], "HasMoreApplications": bool},
 )
 
-_RequiredTagTypeDef = TypedDict("_RequiredTagTypeDef", {"Key": str})
-_OptionalTagTypeDef = TypedDict("_OptionalTagTypeDef", {"Value": str}, total=False)
-
-
-class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
-    pass
-
-
 ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef", {"Tags": List[TagTypeDef]}, total=False
+    "ListTagsForResourceResponseTypeDef", {"Tags": List["TagTypeDef"]}, total=False
 )
 
-KinesisFirehoseOutputTypeDef = TypedDict(
-    "KinesisFirehoseOutputTypeDef", {"ResourceARN": str, "RoleARN": str}
-)
-
-KinesisStreamsOutputTypeDef = TypedDict(
-    "KinesisStreamsOutputTypeDef", {"ResourceARN": str, "RoleARN": str}
-)
-
-LambdaOutputTypeDef = TypedDict("LambdaOutputTypeDef", {"ResourceARN": str, "RoleARN": str})
-
 _RequiredOutputTypeDef = TypedDict(
-    "_RequiredOutputTypeDef", {"Name": str, "DestinationSchema": DestinationSchemaTypeDef}
+    "_RequiredOutputTypeDef", {"Name": str, "DestinationSchema": "DestinationSchemaTypeDef"}
 )
 _OptionalOutputTypeDef = TypedDict(
     "_OptionalOutputTypeDef",
     {
-        "KinesisStreamsOutput": KinesisStreamsOutputTypeDef,
-        "KinesisFirehoseOutput": KinesisFirehoseOutputTypeDef,
-        "LambdaOutput": LambdaOutputTypeDef,
+        "KinesisStreamsOutput": "KinesisStreamsOutputTypeDef",
+        "KinesisFirehoseOutput": "KinesisFirehoseOutputTypeDef",
+        "LambdaOutput": "LambdaOutputTypeDef",
     },
     total=False,
 )
@@ -544,17 +548,13 @@ class OutputTypeDef(_RequiredOutputTypeDef, _OptionalOutputTypeDef):
     pass
 
 
-S3ReferenceDataSourceTypeDef = TypedDict(
-    "S3ReferenceDataSourceTypeDef", {"BucketARN": str, "FileKey": str, "ReferenceRoleARN": str}
-)
-
 _RequiredReferenceDataSourceTypeDef = TypedDict(
     "_RequiredReferenceDataSourceTypeDef",
-    {"TableName": str, "ReferenceSchema": SourceSchemaTypeDef},
+    {"TableName": str, "ReferenceSchema": "SourceSchemaTypeDef"},
 )
 _OptionalReferenceDataSourceTypeDef = TypedDict(
     "_OptionalReferenceDataSourceTypeDef",
-    {"S3ReferenceDataSource": S3ReferenceDataSourceTypeDef},
+    {"S3ReferenceDataSource": "S3ReferenceDataSourceTypeDef"},
     total=False,
 )
 
